<?php

/**
 * Functions for PSTN groups
 *
 * @author Miguel Palmer <mp@beronet.com>
 */
class HelperPstn {
	/**
	 * Get the countries list
	 */
	static function getCountriesList() {
		return 	array(  
				"FCC", "TBR21", "1TR110_DE", "ARGENTINA", "AUSTRALIA", "AUSTRIA", "BAHRAIN",
				"BELGIUM", "BRAZIL", "BULGARIA", "CANADA", "CHILE", "CHINA", "COLOMBIA", "CROATIA",
				"CYPRUS", "CZECH", "DENMARK", "ECUADOR", "EGYPT", "ELSALVADOR", "FINLAND", "FRANCE",
				"GERMANY", "GREECE", "GUAM", "HONGKONG", "HUNGARY", "ICELAND", "INDIA", "INDONESIA",
				"IRELAND", "ISRAEL", "ITALY", "JAPAN", "JORDAN", "KAZAKHSTAN", "KUWAIT", "LATVIA",
				"LEBANON", "LUXEMBOURG", "MACAO", "MALAYSIA", "MALTA", "MEXICO", "MOROCCO", "NETHERLANDS",
				"NEWZEALAND", "NIGERIA", "NORWAY", "OMAN", "PAKISTAN", "PERU", "PHILIPPINES", "POLAND",
				"PORTUGAL", "ROMANIA", "RUSSIA", "SAUDIARABIA", "SINGAPORE", "SLOVAKIA", "SLOVENIA",
				"SOUTHAFRICA", "SOUTHKOREA", "SPAIN", "SWEDEN", "SWITZERLAND", "SYRIA", "TAIWAN", "THAILAND",
				"UAE", "UK", "USA", "YEMEN", "USER"
		);
	}

	/**
	 * Set the POST arguments during submit
	 */
	static function getPostParameters($type_to_get, $options_loaded = array()) {
		// init
		$options = array();
		$arguments = array(); 

		// options
		$wait_oad_list = array('wait', 'dontwait');

		// General arguments
		if ($type_to_get === 'general') {
			$arguments = array(	
						'group' 	  => 'group-name', 'gr_upd' 	     => 'group-name', 'ports' 	=> 'int>0', 'tones' => 'tones'	  , 'chansel' 	 => 'select', 'chansel_dir'   => 'select'	, 
						'overlap_dialing' => 'bool'	 , 'dialtone_digits' => 'int>=0'    , 'ec' 	=> 'bool' , 'ectl'  => 'int-range','clir_on_oad' => 'int>=0', 'addit_options' => 'config-option'
					  );

			$options = array(
                                		'chansel'      => array('standard', 'random', 'roundrobin'),
                                		'chansel_dir'  => array('ascending', 'descending')         ,
                                		'ectl'         => array('min' => 0, 'max' => 15)           ,
					);
		}
		// ISDN arguments
		else if ($type_to_get === 'isdn') {
			$arguments = array(
						'portpullup' 	=> 'int-range'	, 'odt'  => 'int>=0'	, 'country_code' => 'international-code', 'city_code'        		=> 'int>=0'  	, 'local_area_code'		=> 'int>=0',
						'pcmlaw'    	=> 'select'	, 'qsig' => 'bool'	, 'dton' 	 => 'int-range'		, 'oton' 	     		=> 'int-range'	, 'bearer_cap'			=> 'select',
						'screen' 	=> 'bool'	, 'cd'   => 'bool'	, 'pres' 	 => 'bool'		, 'restart_after_link_loss' 	=> 'bool'	, 'from_pstn_src_setting_isdn'	=> 'select',

						'odt_empty_dad' => 'int>=0',

						'isdn_dad_setting' 		=> 'select', 'isdn_dad_setting_manual' 	 	=> 'alphanumeric' ,
						'isdn_oad_setting' 		=> 'select', 'isdn_oad_setting_manual' 		=> 'config-option', 
						'isdn_oad2_setting'		=> 'select', 'isdn_oad2_setting_manual' 	=> 'config-option',
						'isdn_qsigname_setting'	 	=> 'select', 'isdn_qsigname_setting_manual' 	=> 'config-option',
						'isdn_redirected_nr_setting' 	=> 'select', 'isdn_redirected_nr_setting_manual'=> 'config-option'
					  );

			$options = array(
						'bearer_cap'                    => array('SPEECH', 'AUDIO_3_1K', 'AUDIO_7K', 'VIDEO', 'DIGITAL_UNRESTRICTED', 'DIGITAL_RESTRICTED', 'DIGITAL_UNRESTRICTED_TONES'),
                                		'chansel'                       => array('standard', 'random', 'roundrobin')	,
                                		'chansel_dir'                   => array('ascending', 'descending')		,
                                		'dton'                          => array('min' => 0, 'max' => 6)		,
                                		'from_pstn_src_setting_isdn'    => $options_loaded['from_pstn_src_setting_isdn'],
                                		'isdn_dad_setting'              => $options_loaded['callee_id_pstn']		,
                                		'isdn_oad_setting'              => $options_loaded['caller_id_pstn']		,
                                		'isdn_oad2_setting'             => $options_loaded['caller_id_pstn']		,
                                		'isdn_qsigname_setting'         => $options_loaded['caller_id_pstn']		,
                                		'isdn_redirected_nr_setting'    => $options_loaded['caller_id_pstn']		,
                                		'oton'                          => array('min' => 0, 'max' => 6)		,
                                		'pcmlaw'                        => array('default', 'alaw', 'ulaw')		,
                                		'portpullup'                    => array('min' => 0, 'max' => 2)		
					);
		}
		// Analog arguments
		else if ($type_to_get === 'analog') {

			$arguments = array(
						'fxo_connect' => 'select', 'fxo_wait_for_oad' => 'select',  'fxo_call_ending_signal' => 'select', 'fxo_cid_detection_mode' => 'select', 'clip' => 'int>=0', 'cnip' => 'alphanumeric',

						'overlap_dial_timeout_empty_dad' => 'int>0' , 'overlap_dial_timeout'     =>  'int>0' 	, 'message_waiting_method' => 'select',
                        			'from_pstn_src_setting_analog' 	 => 'select', 'fxo_dialtone_passthrough' => 'bool'	,

						'analog_oad_setting' 	 => 'select', 'analog_oad_setting_manual' 	=> 'config-option',
						'analog_display_setting' => 'select', 'analog_display_setting_manual' 	=> 'config-option'
					);

			$options = array(
                                		'analog_oad_setting'            => $options_loaded['caller_id_pstn']		 ,
                                		'analog_display_setting'        => $options_loaded['caller_id_pstn']		 ,
                                		'from_pstn_src_setting_analog'  => array('clip', 'cnip')                         ,
                                		'fxo_connect'                   => array('instant', 'polarity')                  ,
                                		'fxo_wait_for_oad'              => $wait_oad_list 	                         ,
                                		'fxo_call_ending_signal'        => array('unobtainable', 'busy')                 ,
                                		'fxo_cid_detection_mode'        => array('Bellcore', 'ETSI-DTMF', 'ETSI-DTMF-AR'),
                                		'message_waiting_method'        => array('stutter', 'fsk', 'off')                
					);
		}
		// GSM / LTE arguments
		else if ($type_to_get === 'gsm' || $type_to_get === 'lte') {
			$arguments = array(
						'sms_extension'	=> 'phone-char',
						'extension'	=> 'phone-char'
					  );

			$options = array();
		}
		// CAS arguments
		else if ($type_to_get === 'cas') {
			$arguments = array(
						'channels'     => 'int>0' , 't1sigtype' => 'select', 'e1sigtype' => 'select', 'interdigit_timeout_initial' => 'int>=0', 'interdigit_timeout' => 'int>=0', 'fxo_callerid_detection_timeout' => 'int>=0',
						'wait_for_oad' => 'select');

			$options = array( 
						'e1sigtype' 	=> array('mfcr2')		,
						't1sigtype' 	=> array('fxo_ks', 'fxs_ks')	, 			
						'wait_for_oad' 	=> $wait_oad_list
					);

		}

		return array('post' => $arguments, 'options' => $options);
	}

	/**
	 * Port section title (PSTN popups)
	 */
	static function title($ba, $gr, $lif) {
		$query = $ba->select("select distinct type from isdn where lif='" . sqlite_escape_string($lif) . "' union "
			. "select distinct type from gsm where lif='" . sqlite_escape_string($lif) . "' union "
			. "select distinct type from lte where lif='" . sqlite_escape_string($lif) . "' union "
			. "select distinct type from analog where lif='" . sqlite_escape_string($lif) . "' union "
			. "select distinct type from cas where lif='" . sqlite_escape_string($lif) . "'");
		$title = "<b>Li" . $lif . "()</b>";
		while ($entry = $ba->fetch_array($query)) {		
			$title = "<b>Li" . $lif . "(" . $entry['type'] . ")</b>";
		}
		return $title;
	}

	/**
	 * Ports of the port section (PSTN popups)
	 */
	static function ports($ba, $gr, $lif, $table) {
		$where = "";
		if ($table == "isdn" || $table == "analog") {
			$where = " and port_type='" . sqlite_escape_string($_GET['opt']) . "'";
		}
		$query = $ba->select("select * from " . sqlite_escape_string($table) . " where lif='" . sqlite_escape_string($lif) . "' " . $where);
		while ($entry = $ba->fetch_array($query)) {
			$type = explode("-", $entry['type']);
			if (html_entity_decode($entry['gr']) == $gr) {
				$tab .= "<div>Port " . $entry['port'] . "<input type='checkbox' name='ports[]' checked value='" . $entry['port'] . "'></div>";
			} elseif ($entry['gr'] == 'NULL') {
				$tab .= "<div>Port " . $entry['port'] . "<input type='checkbox' name='ports[]' value='" . $entry['port'] . "'></div>";
			} else {
				$tab .= "<div>Port " . $entry['port'] . "<input type='checkbox' name='ports[]' checked disabled='true' value='" . $entry['port'] . "'></div>";
			}
		}
		return $tab;
	}

	/**
	 * Build tones dropdown
	 */
	function tones($ba, $gr, $table) {
		$query = $ba->select("select tones from " . sqlite_escape_string($table) . " where gr='" . sqlite_escape_string($gr) . "'");
		$tones = "";
		while ($entry = $ba->fetch_array($query)) {
			$tones = $entry['tones'];
		}
		exec('/bin/cat /usr/conf/isgw.tones | /bin/grep "^\[.*\]$" ', $ausgabe);
		$ret = "<select class='form-control' name='tones'>";
		foreach ($ausgabe as $value) {
			if ($value == $tones) {
				$ret .= "<option value='" . $value . "' selected>" . $value . "</option>";
			} elseif ($value == "[de]" && $gr == "") {
				$ret .= "<option value='" . $value . "' selected>" . $value . "</option>";
			} elseif ($value != "[general]") {
				$ret .= "<option value='" . $value . "'>" . $value . "</option>";
			}
		}
		$ret .= "</select>";
		return $ret;
	}

	/**
	 * Return generic text field
	 */
	static function textfield($ba, $gr, $col, $table, $default = "") {
		if ($gr != "") {
			$query = $ba->select("select " . sqlite_escape_string($col) . " from " . sqlite_escape_string($table) . " where gr='" . sqlite_escape_string($gr) . "'");
			$value = "";
			while ($entry = $ba->fetch_array($query)) {
				$value = $entry[$col];
			}

			$ret = "<input class='form-control' name='" . $col . "' id='" . $col . "' value='" . $value . "'>";
			return $ret;
		} else {
			$ret = "<input class='form-control' name='" . $col . "' id='" . $col . "' value='" . $default . "'>";
			return $ret;
		}
	}

	/**
	 * Return a generic dropdown field
	 */
	static function dropdown($ba, $gr, $col, $table, $options, $default = "") {
		$query = $ba->select("select distinct " . sqlite_escape_string($col) . " from " . sqlite_escape_string($table) . " where gr='" . sqlite_escape_string($gr) . "'");
		$sel .= "<select class='form-control' name='" . $col . "'>";
		while ($entry = $ba->fetch_array($query)) {
			$default = $entry[$col];
		}
		foreach ($options as $name => $value) {
			($name == $default) ? $sel .= "<option value='" . $name . "' selected>" . $value . "</option>" : $sel .= "<option value='" . $name . "'>" . $value . "</option>";
		}
		$sel .= "</select>";
		return $sel;
	}

	/**
	 * Return a generic checkbox
	 */
	static function checkbox($ba, $gr, $col, $table, $htmlOptions = '', $default = "") {
		$query = $ba->select("select " . sqlite_escape_string($col) . " from " . sqlite_escape_string($table) . " where gr='" . sqlite_escape_string($gr) . "'");
		while ($entry = $ba->fetch_array($query)) {
			if ($entry[$col] == 1)
				$default = "checked";
			else
				$default = "";
		}

		$ret = "<input type='hidden' name='$col' value='0'>"
			. "<input type='checkbox' name='$col' id='$col'  value='1' $default $htmlOptions>";
		return $ret;
	}

	/**
	 * Additional config string bei einem Update
	 */
	function showdefmc($config_values, $letter, $table) {
		require_once '/usr/local/www/berogui/includes/Helper/Helper.php';
		$zeilen = Helper::getConfigFromIsgw();
		foreach ($zeilen as $zeile) {
			if (stripos($zeile, '[') === 0) {
				preg_match("/\[(?<bez>.+)\]\[(?<name>.+)\][\s]*(?<desc>.+)[\s]*\<(?<val>.*)\>[\s]*'(?<def>.*)'/", $zeile, $res);
				if (!in_array($res['name'], $config_values) && ($res['bez'] == $letter || $res['bez'] == "p" || $res['bez'] == "*"))
					echo "<script>
                            var extra_tooltip=document.getElementById('extra_tooltip');
                            extra_tooltip.innerHTML=extra_tooltip.innerHTML+'<p>" . DIALPLAN_OPTION_DIS . "<b>&nbsp;" . $res['name'] . "</b><br>" . DIALPLAN_VALUES_DIS . "<b>&nbsp;&lt;" . $res['val'] . "&gt;</b><br>Default:<b>&nbsp;" . $res['def'] . "</b><br><i>" . htmlspecialchars($res['desc'], ENT_QUOTES) . "</i></p><br>';
			</script>";
			}
		}
		$ba = new beroAri();
		$query = $ba->select("select config from " . sqlite_escape_string($table) . " where gr='" . sqlite_escape_string($_GET['gr']) . "' group by gr");
		while ($entry = $ba->fetch_array($query)) {
			$config = $entry['config'];
		}
		if ($config != "") {
			$configs = explode(',', $config);
			foreach ($configs as $value) {
				$key = explode('=', $value, 2);
				if ($key[0] != "" && $key[1] != "" && !in_array($key[0], $config_values)) {
					echo "<script>var addit_options=document.getElementById('addit_options');
                            	if (addit_options.innerHTML=='')
                                    addit_options.innerHTML='" . $key[0] . "=" . $key[1] . "';
				else
                                    addit_options.innerHTML=addit_options.innerHTML+'\\n" . $key[0] . "=" . $key[1] . "';</script>";
				} elseif ($key[0] != "" && $key[1] == "" && !in_array($key[0], $config_values)) {
					echo "<script>var addit_options=document.getElementById('addit_options');
                                    if (addit_options.innerHTML=='')
                                        addit_options.innerHTML='" . $key[0] . "=';
                                    else
                                        addit_options.innerHTML=addit_options.innerHTML+'\\n" . $key[0] . "=';</script>";
				}
			}
		}
	}

	/**
	 * Additional config string beim Hinzufügen einer Portgruppe
	 */
	function show_confadd($config_values, $letter) {
		require_once '/usr/local/www/berogui/includes/Helper/Helper.php';
		$zeilen = Helper::getConfigFromIsgw();
		foreach ($zeilen as $zeile) {
			if (stripos($zeile, '[') === 0) {
				preg_match("/\[(?<bez>.+)\]\[(?<name>.+)\][\s]*(?<desc>.+)[\s]*\<(?<val>.*)\>[\s]*'(?<def>.*)'/", $zeile, $res);
				if (!in_array($res['name'], $config_values) && ($res['bez'] == $letter || $res['bez'] == "p" || $res['bez'] == "*"))
					echo "<script>
			var extra_tooltip=document.getElementById('extra_tooltip');
			extra_tooltip.innerHTML=extra_tooltip.innerHTML+'<p>" . DIALPLAN_OPTION_DIS . "<b>&nbsp;" . $res['name'] . "</b><br>" . DIALPLAN_VALUES_DIS . "<b>&nbsp;&lt;" . $res['val'] . "&gt;</b><br>Default:<b>&nbsp;" . $res['def'] . "</b><br><i>" . htmlspecialchars($res['desc'], ENT_QUOTES) . "</i></p><br>';
		</script>";
			}
		}
	}

}
